@@ -193,7 +193,10 @@ def flattenlist(l):
     return(flatlist)
 
 def parsetodict(s):
-    r = Syntax().parseString(s).asList()
+    try:
+        r = Syntax().parseString(s).asList()
+    except:
+        return {}
     res = getintervalasdict(r)
 
     xres = flattenlist(res)
@@ -212,10 +215,10 @@ def simpletofit(step,message_index=0,name=''):
 
     if unit == 'seconds':
         d['durationType'] = 'Time'
-        d['durationValue'] = value
+        d['durationValue'] = value*1000
     else:
         d['durationType'] = 'Distance'
-        d['durationValue'] = value
+        d['durationValue'] = value*100
 
     d['intensity'] = 'Active'
     if type == 'rest':
@@ -226,13 +229,13 @@ def simpletofit(step,message_index=0,name=''):
         targetunit = step['targetunit']
         if targetunit == 'W':
             d['targetType'] = 'Power'
-            d['targetValue'] = target
+            d['targetValue'] = target+1000
         if targetunit == 'spm':
             d['targetType'] = 'Cadence'
             d['targetValue'] = target
         if targetunit in ['bpm','hr']:
             d['targetType'] = 'HeartRate'
-            d['targetValue'] = target
+            d['targetValue'] = target+100
     except KeyError:
         pass
 
@@ -255,7 +258,11 @@ def tofitdict(steps,name='',sport='rowing'):
     return d
 
 def parse(s):
-    r = Syntax().parseString(s).asList()
+    try:
+        r = Syntax().parseString(s).asList()
+    except:
+        return []
+    
     res = getinterval(r)
 
     xres = []
